summaryrefslogtreecommitdiff
path: root/service/entry.go
diff options
context:
space:
mode:
Diffstat (limited to 'service/entry.go')
-rw-r--r--service/entry.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/service/entry.go b/service/entry.go
index f2cbac28..b8da6514 100644
--- a/service/entry.go
+++ b/service/entry.go
@@ -8,8 +8,8 @@ const (
// StatusUndefined when service bus can not find the service.
StatusUndefined = iota
- // StatusRegistered hasStatus setStatus when service has been registered in container.
- StatusRegistered
+ // StatusInactive hasStatus setStatus when service has been registered in container.
+ StatusInactive
// StatusOK hasStatus setStatus when service has been properly configured.
StatusOK